@@ -244,7 +244,7 @@ impl Party2SecondMessage {
         if party_one_pk_commitment
             != &HashCommitment::create_commitment_with_user_defined_randomness(
                 &party_one_public_share.bytes_compressed_to_big_int(),
-                &party_one_pk_commitment_blind_factor,
+                party_one_pk_commitment_blind_factor,
             )
         {
             flag = false
@@ -255,14 +255,14 @@ impl Party2SecondMessage {
                 &party_one_d_log_proof
                     .pk_t_rand_commitment
                     .bytes_compressed_to_big_int(),
-                &party_one_zk_pok_blind_factor,
+                party_one_zk_pok_blind_factor,
             )
         {
             flag = false
         };
 
         assert!(flag);
-        DLogProof::verify(&party_one_d_log_proof)?;
+        DLogProof::verify(party_one_d_log_proof)?;
         Ok(Party2SecondMessage {})
     }
 }
